@@ -364,11 +364,11 @@ class NumerousClient:
 
         return json.loads(model.model), model.files
 
-    def set_scenario_data_tags(self, tags, scenario=None):
-        if scenario is None:
-            scenario = self._scenario
+    #def set_scenario_data_tags(self, tags, scenario=None):
+    #    if scenario is None:
+    #        scenario = self._scenario
 
-        self._base_client.SetScenarioDataTags(spm_pb2.ScenarioDataTags(project=self._project, scenario=scenario, tags=tags))
+    #    self._base_client.SetScenarioDataTags(spm_pb2.ScenarioDataTags(project=self._project, scenario=scenario, tags=tags))
 
     def set_scenario_progress(self, message, status, progress=None, clean=False, scenario=None, force=False):
         if scenario is None:
@@ -481,6 +481,11 @@ class NumerousClient:
 
         upload()
 
+    def get_timeseries_stats(self, scenario=None):
+        if scenario is None:
+            scenario = self._scenario
+
+        return self._base_client.GetScenarioDataStats(spm_pb2.Scenario(scenario=scenario))
 
     def get_timeseries_meta_data(self, scenario=None):
         if scenario is None:
